##  Executing Transformations in the Transformations Explorer
Do the following:
  1. Select the transformation items you want to execute.
The Review and Execute option becomes active when all selected items have the status ‘Ready to Execute’. You can check the Status column to see if a transformation has already been executed or not.
  2. Choose Review and Execute.
Review the transformation items that you selected.
  3. Choose Execute Now.


**Tip**
To quickly find items that are ready to execute, filter by Status and choose Ready to execute.
